Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/mcp_atlassian/__init__.py | (no class) | 46 | 26 | 0 | 43%
src/mcp_atlassian/config.py | ConfluenceConfig | 1 | 1 | 0 | 0%
src/mcp_atlassian/config.py | JiraConfig | 1 | 1 | 0 | 0%
src/mcp_atlassian/config.py | (no class) | 15 | 0 | 0 | 100%
src/mcp_atlassian/confluence.py | ConfluenceFetcher | 102 | 28 | 0 | 73%
src/mcp_atlassian/confluence.py | (no class) | 19 | 0 | 0 | 100%
src/mcp_atlassian/document_types.py | Document | 0 | 0 | 0 | 100%
src/mcp_atlassian/document_types.py | (no class) | 5 | 0 | 0 | 100%
src/mcp_atlassian/jira.py | JiraFetcher | 385 | 181 | 0 | 53%
src/mcp_atlassian/jira.py | (no class) | 30 | 0 | 0 | 100%
src/mcp_atlassian/preprocessing.py | TextPreprocessor | 70 | 11 | 0 | 84%
src/mcp_atlassian/preprocessing.py | (no class) | 35 | 18 | 0 | 49%
src/mcp_atlassian/server.py | (no class) | 267 | 267 | 0 | 0%
Total |  | 976 | 533 | 0 | 45%

No items found using the specified filter.